@@ -1,12 +1,16 @@
 from typing import TYPE_CHECKING
 
-from ..errors import TealCompileError, TealInputError
-from ..types import TealType, require_type, types_match
-from ..ir import TealSimpleBlock, TealConditionalBlock
-from .expr import Expr
+from pyteal.errors import (
+    TealCompileError,
+    TealInputError,
+)
+from pyteal.types import TealType, require_type
+from pyteal.ir import TealSimpleBlock, TealConditionalBlock
+from pyteal.ast.expr import Expr
+from pyteal.ast.seq import _use_seq_if_multiple
 
 if TYPE_CHECKING:
-    from ..compiler import CompileOptions
+    from pyteal.compiler import CompileOptions
 
 
 class If(Expr):
@@ -78,6 +82,11 @@ class If(Expr):
     def type_of(self):
         if self.thenBranch is None:
             raise TealCompileError("If expression must have a thenBranch", self)
+
+        if self.elseBranch is None:
+            # if there is only a thenBranch, it must evaluate to TealType.none
+            require_type(self.thenBranch, TealType.none)
+
         return self.thenBranch.type_of()
 
     def has_return(self):
@@ -91,10 +100,12 @@ class If(Expr):
         # otherwise, this expression has a return op only if both branches result in a return op
         return self.thenBranch.has_return() and self.elseBranch.has_return()
 
-    def Then(self, thenBranch: Expr):
+    def Then(self, thenBranch: Expr, *then_branch_multi: Expr):
         if not self.alternateSyntaxFlag:
             raise TealInputError("Cannot mix two different If syntax styles")
 
+        thenBranch = _use_seq_if_multiple(thenBranch, *then_branch_multi)
+
         if not self.elseBranch:
             self.thenBranch = thenBranch
         else:
@@ -115,11 +126,17 @@ class If(Expr):
             self.elseBranch.ElseIf(cond)
         return self
 
-    def Else(self, elseBranch: Expr):
+    def Else(self, elseBranch: Expr, *else_branch_multi: Expr):
         if not self.alternateSyntaxFlag:
             raise TealInputError("Cannot mix two different If syntax styles")
 
+        if not self.thenBranch:
+            raise TealInputError("Must set Then branch before Else branch")
+
+        elseBranch = _use_seq_if_multiple(elseBranch, *else_branch_multi)
+
         if not self.elseBranch:
+            require_type(elseBranch, self.thenBranch.type_of())
             self.elseBranch = elseBranch
         else:
             if not isinstance(self.elseBranch, If):
