@@ -1,12 +1,12 @@
 from typing import TYPE_CHECKING
 
-from ..types import TealType, require_type
-from ..errors import verifyTealVersion
-from ..ir import TealOp, Op, TealBlock
-from .expr import Expr
+from pyteal.types import TealType, require_type
+from pyteal.errors import verifyTealVersion
+from pyteal.ir import TealOp, Op, TealBlock
+from pyteal.ast.expr import Expr
 
 if TYPE_CHECKING:
-    from ..compiler import CompileOptions
+    from pyteal.compiler import CompileOptions
 
 
 class UnaryExpr(Expr):
@@ -31,7 +31,7 @@ class UnaryExpr(Expr):
         return TealBlock.FromOp(options, TealOp(self, self.op), self.arg)
 
     def __str__(self):
-        return "({} {})".format(self.op, self.arg)
+        return "({} {})".format(str(self.op).title().replace("_", ""), self.arg)
 
     def type_of(self):
         return self.outputType
