@@ -1,13 +1,13 @@
 from typing import TYPE_CHECKING, Optional
+from pyteal.ast.seq import _use_seq_if_multiple
 
-from ..errors import TealCompileError
-from ..types import TealType, require_type
-from ..ir import TealSimpleBlock, TealConditionalBlock
-from .expr import Expr
-from .seq import Seq
+from pyteal.errors import TealCompileError
+from pyteal.types import TealType, require_type
+from pyteal.ir import TealSimpleBlock, TealConditionalBlock
+from pyteal.ast.expr import Expr
 
 if TYPE_CHECKING:
-    from ..compiler import CompileOptions
+    from pyteal.compiler import CompileOptions
 
 
 class While(Expr):
@@ -22,6 +22,14 @@ class While(Expr):
 
         Args:
             cond: The condition to check. Must evaluate to uint64.
+
+        Example:
+            .. code-block:: python
+
+                i = ScratchVar()
+                i.store(Int(0))
+                While(i.load() < pt.Int(2))
+                    .Do(Pop(Int(1)), i.store(i.load() + Int(1)))
         """
         super().__init__()
         require_type(cond, TealType.uint64)
@@ -53,7 +61,7 @@ class While(Expr):
             block.setNextBlock(end)
 
         for block in continueBlocks:
-            block.setNextBlock(doStart)
+            block.setNextBlock(condStart)
 
         return condStart, end
 
@@ -71,9 +79,12 @@ class While(Expr):
     def has_return(self):
         return False
 
-    def Do(self, doBlock: Expr):
+    def Do(self, doBlock: Expr, *do_block_multi: Expr):
         if self.doBlock is not None:
             raise TealCompileError("While expression already has a doBlock", self)
+
+        doBlock = _use_seq_if_multiple(doBlock, *do_block_multi)
+
         require_type(doBlock, TealType.none)
         self.doBlock = doBlock
         return self
