@@ -1,29 +1,29 @@
 from typing import List, Tuple, Set, Dict, Optional, cast
 
-from .optimizer import OptimizeOptions, apply_global_optimizations
+from pyteal.compiler.optimizer import OptimizeOptions, apply_global_optimizations
 
-from ..types import TealType
-from ..ast import (
+from pyteal.types import TealType
+from pyteal.ast import (
     Expr,
     Return,
     Seq,
     SubroutineDefinition,
     SubroutineDeclaration,
 )
-from ..ir import Mode, TealComponent, TealOp, TealBlock, TealSimpleBlock
-from ..errors import TealInputError, TealInternalError
+from pyteal.ir import Mode, Op, TealComponent, TealOp, TealBlock, TealSimpleBlock
+from pyteal.errors import TealInputError, TealInternalError
 
-from .sort import sortBlocks
-from .flatten import flattenBlocks, flattenSubroutines
-from .scratchslots import (
+from pyteal.compiler.sort import sortBlocks
+from pyteal.compiler.flatten import flattenBlocks, flattenSubroutines
+from pyteal.compiler.scratchslots import (
     assignScratchSlotsToSubroutines,
     collect_unoptimized_slots,
 )
-from .subroutines import (
+from pyteal.compiler.subroutines import (
     spillLocalSlotsDuringRecursion,
     resolveSubroutines,
 )
-from .constants import createConstantBlocks
+from pyteal.compiler.constants import createConstantBlocks
 
 MAX_TEAL_VERSION = 6
 MIN_TEAL_VERSION = 2
@@ -70,7 +70,7 @@ class CompileOptions:
     def exitLoop(self) -> Tuple[List[TealSimpleBlock], List[TealSimpleBlock]]:
         if len(self.breakBlocksStack) == 0 or len(self.continueBlocksStack) == 0:
             raise TealInternalError("Cannot exit loop when no loop is active")
-        return (self.breakBlocksStack.pop(), self.continueBlocksStack.pop())
+        return self.breakBlocksStack.pop(), self.continueBlocksStack.pop()
 
 
 def verifyOpsForVersion(teal: List[TealComponent], version: int):
@@ -128,31 +128,71 @@ def compileSubroutine(
 
     if not ast.has_return():
         if ast.type_of() == TealType.none:
-            ast = Seq([ast, Return()])
+            ret_expr = Return()
+            ret_expr.trace = ast.trace
+            seq_expr = Seq([ast, ret_expr])
+            seq_expr.trace = ret_expr.trace
+            ast = seq_expr
         else:
-            ast = Return(ast)
+            ret_expr = Return(ast)
+            ret_expr.trace = ast.trace
+            ast = ret_expr
 
     options.setSubroutine(currentSubroutine)
+
     start, end = ast.__teal__(options)
     start.addIncoming()
     start.validateTree()
 
+    if (
+        currentSubroutine is not None
+        and currentSubroutine.get_declaration().deferred_expr is not None
+    ):
+        # this represents code that should be inserted before each retsub op
+        deferred_expr = cast(Expr, currentSubroutine.get_declaration().deferred_expr)
+
+        for block in TealBlock.Iterate(start):
+            if not any(op.getOp() == Op.retsub for op in block.ops):
+                continue
+
+            if len(block.ops) != 1:
+                # we expect all retsub ops to be in their own block at this point since
+                # TealBlock.NormalizeBlocks has not yet been used
+                raise TealInternalError(
+                    f"Expected retsub to be the only op in the block, but there are {len(block.ops)} ops"
+                )
+
+            # we invoke __teal__ here and not outside of this loop because the same block cannot be
+            # added in multiple places to the control flow graph
+            deferred_start, deferred_end = deferred_expr.__teal__(options)
+            deferred_start.addIncoming()
+            deferred_start.validateTree()
+
+            # insert deferred blocks between the previous block(s) and this one
+            deferred_start.incoming = block.incoming
+            block.incoming = [deferred_end]
+            deferred_end.nextBlock = block
+
+            for prev in deferred_start.incoming:
+                prev.replaceOutgoing(block, deferred_start)
+
+            if block is start:
+                # this is the start block, replace start
+                start = deferred_start
+
+    start.validateTree()
+
     start = TealBlock.NormalizeBlocks(start)
     start.validateTree()
 
-    order = sortBlocks(start, end)
-    teal = flattenBlocks(order)
-
-    verifyOpsForVersion(teal, options.version)
-    verifyOpsForMode(teal, options.mode)
-
     subroutine_start_blocks[currentSubroutine] = start
     subroutine_end_blocks[currentSubroutine] = end
 
     referencedSubroutines: Set[SubroutineDefinition] = set()
-    for stmt in teal:
-        for subroutine in stmt.getSubroutines():
-            referencedSubroutines.add(subroutine)
+    for block in TealBlock.Iterate(start):
+        for stmt in block.ops:
+            for subroutine in stmt.getSubroutines():
+                referencedSubroutines.add(subroutine)
 
     if currentSubroutine is not None:
         subroutineGraph[currentSubroutine] = referencedSubroutines
@@ -160,7 +200,7 @@ def compileSubroutine(
     newSubroutines = referencedSubroutines - subroutine_start_blocks.keys()
     for subroutine in sorted(newSubroutines, key=lambda subroutine: subroutine.id):
         compileSubroutine(
-            subroutine.getDeclaration(),
+            subroutine.get_declaration(),
             options,
             subroutineGraph,
             subroutine_start_blocks,
@@ -256,6 +296,9 @@ def compileTeal(
     subroutineLabels = resolveSubroutines(subroutineMapping)
     teal = flattenSubroutines(subroutineMapping, subroutineLabels)
 
+    verifyOpsForVersion(teal, options.version)
+    verifyOpsForMode(teal, options.mode)
+
     if assembleConstants:
         if version < 3:
             raise TealInternalError(
