@@ -1,12 +1,11 @@
 import re
 from typing import List, Dict, Set, Optional, TypeVar
 from collections import OrderedDict
-from itertools import chain
 
-from ..errors import TealInputError
-from ..types import TealType
-from ..ast import SubroutineDefinition
-from ..ir import TealComponent, TealOp, Op
+from pyteal.errors import TealInputError
+from pyteal.types import TealType
+from pyteal.ast import SubroutineDefinition
+from pyteal.ir import TealComponent, TealOp, Op
 
 # generic type variable
 Node = TypeVar("Node")
@@ -168,7 +167,7 @@ def spillLocalSlotsDuringRecursion(
                 # reentrySubroutineCalls should have a length of 1, since calledSubroutines has a
                 # maximum length of 1
                 reentrySubroutineCall = reentrySubroutineCalls[0]
-                numArgs = reentrySubroutineCall.argumentCount()
+                numArgs = reentrySubroutineCall.argument_count()
 
                 digArgs = True
                 coverSpilledSlots = False
@@ -215,7 +214,7 @@ def spillLocalSlotsDuringRecursion(
 
                 hideReturnValueInFirstSlot = False
 
-                if subroutine.returnType != TealType.none:
+                if subroutine.return_type != TealType.none:
                     # if the subroutine returns a value on the stack, we need to preserve this after
                     # restoring all local slots.
 
@@ -246,7 +245,7 @@ def spillLocalSlotsDuringRecursion(
                         # clear out the duplicate arguments that were dug up previously, since dig
                         # does not pop the dug values -- once we use cover/uncover to properly set up
                         # the spilled slots, this will no longer be necessary
-                        if subroutine.returnType != TealType.none:
+                        if subroutine.return_type != TealType.none:
                             # if there is a return value on top of the stack, we need to preserve
                             # it, so swap it with the subroutine argument that's below it on the
                             # stack
